@@ -1,7 +1,6 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
-import commands
-from subprocess import Popen,PIPE,call,STDOUT
+from subprocess import Popen, PIPE, call, STDOUT
 import os
 import signal
 import re
@@ -15,17 +14,19 @@ import gi
 gi.require_version('Polkit', '1.0')
 gi.require_version('Gtk', '3.0')
 gi.require_version('UDisks', '2.0')
+gi.require_version('XApp', '1.0')
 
-from gi.repository import GObject, Gio, Polkit, Gtk, GLib, UDisks
+from gi.repository import GObject, Gio, Polkit, Gtk, GLib, UDisks, XApp
 
 try:
+    gi.require_version('Unity', '7.0')
     from gi.repository import Unity
     Using_Unity = True
-except ImportError:
+except Exception:
     Using_Unity = False
 
 if Using_Unity:
-    launcher = Unity.LauncherEntry.get_for_desktop_id ("pearlstick.desktop")
+    launcher = Unity.LauncherEntry.get_for_desktop_id("pearlstick.desktop")
 
 APP = 'pearlstick'
 LOCALE_DIR = "/usr/share/pearllinux/locale"
@@ -37,21 +38,28 @@ _ = gettext.gettext
 # https://technet.microsoft.com/en-us/library/bb490925.aspx
 FORBIDDEN_CHARS = ["*", "?", "/", "\\", "|", ".", ",", ";", ":", "+", "=", "[", "]", "<", ">", "\""]
 
-GObject.threads_init()
+
+# https://wiki.gnome.org/PyGObject/Threading
+# GObject.threads_init()
+
 
 def print_timing(func):
     def wrapper(*arg):
         t1 = time.time()
         res = func(*arg)
         t2 = time.time()
-        print '%s took %0.3f ms' % (func.func_name, (t2-t1)*1000.0)
+        print('%s took %0.3f ms' % (func.__name__, (t2 - t1) * 1000.0))
         return res
+
     return wrapper
 
-class PearlStick:
-    def __init__(self, iso_path=None, usb_path=None, filesystem=None, mode=None, debug=False):
 
-        self.debug = debug
+# noinspection PyUnusedLocal
+class PearlStick:
+    def __init__(self, iso_path_arg=None, usb_path_arg=None, filesystem_arg=None, mode_arg=None, debug_arg=False):
+
+        self.debug = debug_arg
+        self.filesystem = filesystem_arg
 
         def devices_changed_callback(client):
             self.get_devices()
@@ -65,6 +73,8 @@ class PearlStick:
 
         self.process = None
         self.source_id = None
+        self.dev = None
+        self.write_progress = None
 
         self.wTree.set_translation_domain(APP)
 
@@ -73,10 +83,10 @@ class PearlStick:
         self.ddpid = 0
 
         self.emergency_dialog = self.wTree.get_object("emergency_dialog")
-        self.confirm_dialog =  self.wTree.get_object("confirm_dialog")
+        self.confirm_dialog = self.wTree.get_object("confirm_dialog")
         self.success_dialog = self.wTree.get_object("success_dialog")
 
-        if mode == "iso":
+        if mode_arg == "iso":
             self.mode = "normal"
             self.devicelist = self.wTree.get_object("device_combobox")
             self.label = self.wTree.get_object("to_label")
@@ -84,9 +94,14 @@ class PearlStick:
             self.go_button = self.wTree.get_object("write_button")
             self.go_button.set_label(_("Write"))
             self.logview = self.wTree.get_object("detail_text")
-            self.progress = self.wTree.get_object("progressbar")
+            self.progressbar = self.wTree.get_object("progressbar")
             self.chooser = self.wTree.get_object("filechooserbutton")
 
+            # Making file chooser accessible for users with screen reader
+            label = self.wTree.get_object("label_write_image")
+            button = self.chooser.get_children()[0]
+            label.set_mnemonic_widget(button)
+
             # Devicelist model
             self.devicemodel = Gtk.ListStore(str, str)
 
@@ -100,33 +115,32 @@ class PearlStick:
             self.window = self.wTree.get_object("main_dialog")
             self.window.connect("destroy", self.close)
 
-            # set default file filter to *.img
-
+            # set default file filter to *.iso/*.img
             filt = Gtk.FileFilter()
-            filt.add_pattern("*.img")
-            filt.add_pattern("*.iso")
+            filt.add_pattern("*.[iI][mM][gG]")
+            filt.add_pattern("*.[iI][sS][oO]")
             self.chooser.set_filter(filt)
 
             # set callbacks
 
-            dict = {
-                    "on_cancel_button_clicked" : self.close,
-                    "on_emergency_button_clicked" : self.emergency_ok,
-                    "on_success_button_clicked" : self.success_ok,
-                    "on_confirm_cancel_button_clicked" : self.confirm_cancel}
-            self.wTree.connect_signals(dict)
+            callbacks = {
+                "on_cancel_button_clicked": self.close,
+                "on_emergency_button_clicked": self.emergency_ok,
+                "on_success_button_clicked": self.success_ok,
+                "on_confirm_cancel_button_clicked": self.confirm_cancel}
+            self.wTree.connect_signals(callbacks)
 
             self.devicelist.connect("changed", self.device_selected)
             self.go_button.connect("clicked", self.do_write)
             self.chooser.connect("file-set", self.file_selected)
 
-            if iso_path:
-                if os.path.exists(iso_path):
-                    self.chooser.set_filename(iso_path)
+            if iso_path_arg:
+                if os.path.exists(iso_path_arg):
+                    self.chooser.set_filename(iso_path_arg)
                     self.file_selected(self.chooser)
 
-        if mode == "format":
-            self.mode="format"
+        if mode_arg == "format":
+            self.mode = "format"
             self.devicelist = self.wTree.get_object("formatdevice_combobox")
             self.label = self.wTree.get_object("formatdevice_label")
             self.expander = self.wTree.get_object("formatdetail_expander")
@@ -139,15 +153,15 @@ class PearlStick:
             self.window = self.wTree.get_object("format_window")
             self.window.connect("destroy", self.close)
 
-            self.format_progressbar = self.wTree.get_object("format_progressbar")
+            self.progressbar = self.wTree.get_object("format_progressbar")
             self.filesystemlist = self.wTree.get_object("filesystem_combobox")
             # set callbacks
-            dict = {
-                    "on_cancel_button_clicked" : self.close,
-                    "on_emergency_button_clicked" : self.emergency_ok,
-                    "on_success_button_clicked" : self.success_ok,
-                    "on_confirm_cancel_button_clicked" : self.confirm_cancel}
-            self.wTree.connect_signals(dict)
+            callbacks = {
+                "on_cancel_button_clicked": self.close,
+                "on_emergency_button_clicked": self.emergency_ok,
+                "on_success_button_clicked": self.success_ok,
+                "on_confirm_cancel_button_clicked": self.confirm_cancel}
+            self.wTree.connect_signals(callbacks)
 
             self.go_button.connect("clicked", self.do_format)
             self.filesystemlist.connect("changed", self.filesystem_selected)
@@ -156,9 +170,10 @@ class PearlStick:
             # Filesystemlist
             self.fsmodel = Gtk.ListStore(str, str, int, bool, bool)
             #                     id       label    max-length force-upper-case   force-alpha-numeric
-            self.fsmodel.append(["fat32", "FAT32",      11,        True,                True])
-            self.fsmodel.append(["ntfs",  "NTFS",       32,        False,               False])
-            self.fsmodel.append(["ext4",  "EXT4",       16,        False,               False])
+            self.fsmodel.append(["fat32", "FAT32", 11, True, True])
+            self.fsmodel.append(["exfat", "exFAT", 15, False, False])
+            self.fsmodel.append(["ntfs", "NTFS", 32, False, False])
+            self.fsmodel.append(["ext4", "EXT4", 16, False, False])
             self.filesystemlist.set_model(self.fsmodel)
 
             # Renderer
@@ -177,27 +192,27 @@ class PearlStick:
             self.filesystemlist.set_sensitive(True)
             # Default's to fat32
             self.filesystemlist.set_active(0)
-            if filesystem is not None:
-                iter = model.get_iter_first()
-                while iter is not None:
-                    value = model.get_value(iter, 0)
-                    if value == filesystem:
-                        self.filesystemlist.set_active_iter(iter)
-                    iter = model.iter_next(iter)
+            if filesystem_arg is not None:
+                itererator = self.fsmodel.get_iter_first()
+                while itererator is not None:
+                    value = self.fsmodel.get_value(itererator, 0)
+                    if value == filesystem_arg:
+                        self.filesystemlist.set_active_iter(itererator)
+                    itererator = self.fsmodel.iter_next(itererator)
 
             self.filesystem_selected(self.filesystemlist)
             self.get_devices()
 
-            if usb_path is not None:
-                iter = self.devicemodel.get_iter_first()
-                while iter is not None:
-                    value = self.devicemodel.get_value(iter, 0)
-                    if usb_path in value:
-                        self.devicelist.set_active_iter(iter)
-                    iter = self.devicemodel.iter_next(iter)
+            if usb_path_arg is not None:
+                itererator = self.devicemodel.get_iter_first()
+                while itererator is not None:
+                    value = self.devicemodel.get_value(itererator, 0)
+                    if usb_path_arg in value:
+                        self.devicelist.set_active_iter(itererator)
+                    itererator = self.devicemodel.iter_next(itererator)
 
         self.window.show_all()
-        if self.mode=="format":
+        if self.mode == "format":
             self.expander.hide()
         self.log = self.logview.get_buffer()
 
@@ -228,11 +243,11 @@ class PearlStick:
                                 name = block.get_property('device')
                                 name = ''.join([i for i in name if not i.isdigit()])
 
-                            driveVendor = str(drive.get_property('vendor'))
-                            driveModel = str(drive.get_property('model'))
+                            drive_vendor = str(drive.get_property('vendor'))
+                            drive_model = str(drive.get_property('model'))
 
-                            if driveVendor.strip() != "":
-                                driveModel = "%s %s" % (driveVendor, driveModel)
+                            if drive_vendor.strip() != "":
+                                drive_model = "%s %s" % (drive_vendor, drive_model)
 
                             if size >= 1000000000000:
                                 size = "%.0fTB" % round(size / 1000000000000)
@@ -245,7 +260,7 @@ class PearlStick:
                             else:
                                 size = "%.0fB" % round(size)
 
-                            item = "%s (%s) - %s" % (driveModel, name, size)
+                            item = "%s (%s) - %s" % (drive_model, name, size)
 
                             if item not in dct:
                                 dct.append(item)
@@ -254,18 +269,18 @@ class PearlStick:
         self.devicelist.set_model(self.devicemodel)
 
     def device_selected(self, widget):
-        iter = self.devicelist.get_active_iter()
-        if iter is not None:
-            self.dev = self.devicemodel.get_value(iter, 0)
+        iterator = self.devicelist.get_active_iter()
+        if iterator is not None:
+            self.dev = self.devicemodel.get_value(iterator, 0)
             self.go_button.set_sensitive(True)
 
     def filesystem_selected(self, widget):
-        iter = self.filesystemlist.get_active_iter()
-        if iter is not None:
-            self.filesystem = self.fsmodel.get_value(iter, 0)
+        itererator = self.filesystemlist.get_active_iter()
+        if itererator is not None:
+            self.filesystem = self.fsmodel.get_value(itererator, 0)
             self.activate_devicelist()
 
-            self.label_entry.set_max_length(self.fsmodel.get_value(iter, 2))
+            self.label_entry.set_max_length(self.fsmodel.get_value(itererator, 2))
             self.on_label_entry_text_changed(self, self.label_entry)
 
     def file_selected(self, widget):
@@ -276,6 +291,7 @@ class PearlStick:
 
         active_iter = self.filesystemlist.get_active_iter()
         value = self.fsmodel.get_value(active_iter, 0)
+        cursor_pos = self.label_entry.props.cursor_position
 
         if self.fsmodel.get_value(active_iter, 3):
             old_text = self.label_entry.get_text()
@@ -293,12 +309,13 @@ class PearlStick:
 
         length = self.label_entry.get_buffer().get_length()
         self.label_entry.select_region(length, -1)
+        self.label_entry.set_position(cursor_pos)
 
         self.label_entry.handler_unblock(self.label_entry_changed_id)
 
     def do_format(self, widget):
         if self.debug:
-            print "DEBUG: Format %s as %s" % (self.dev, self.filesystem)
+            print("DEBUG: Format %s as %s" % (self.dev, self.filesystem))
             return
 
         self.udisks_client.handler_block(self.udisk_listener_id)
@@ -323,27 +340,33 @@ class PearlStick:
     def check_format_job(self):
         self.process.poll()
         if self.process.returncode is None:
-            self.format_progressbar.pulse()
+            self.pulse_progress()
             return True
         else:
-            GObject.idle_add(self.format_job_done, self.process.returncode)
+            GLib.idle_add(self.format_job_done, self.process.returncode)
             self.process = None
             return False
 
-    def raw_format(self, usb_path, fstype, label):
+    def raw_format(self, usb_path_arg, fstype, label):
         if os.geteuid() > 0:
-            launcher='pkexec'
-            self.process = Popen([launcher,'/usr/bin/python2', '-u', '/usr/lib/pearlstick/raw_format.py','-d',usb_path,'-f',fstype, '-l', label, '-u', str(os.geteuid()), '-g', str(os.getgid())], shell=False, stdout=PIPE,  preexec_fn=os.setsid)
+            polkit_exec = 'pkexec'
+            self.process = Popen(
+                [polkit_exec, '/usr/bin/python3', '-u', '/usr/lib/pearlstick/raw_format.py', '-d', usb_path_arg,
+                 '-f', fstype, '-l', label, '-u', str(os.geteuid()), '-g', str(os.getgid())],
+                shell=False, stdout=PIPE, preexec_fn=os.setsid)
         else:
-            self.process = Popen(['/usr/bin/python2', '-u', '/usr/lib/pearlstick/raw_format.py','-d',usb_path,'-f',fstype, '-l', label, '-u', str(os.geteuid()), '-g', str(os.getgid())], shell=False, stdout=PIPE,  preexec_fn=os.setsid)
+            self.process = Popen(
+                ['/usr/bin/python3', '-u', '/usr/lib/pearlstick/raw_format.py', '-d', usb_path_arg,
+                 '-f', fstype, '-l', label, '-u', str(os.geteuid()), '-g', str(os.getgid())],
+                shell=False, stdout=PIPE, preexec_fn=os.setsid)
 
-        self.format_progressbar.show()
-        self.format_progressbar.pulse()
+        self.progressbar.show()
+        self.pulse_progress()
 
-        GObject.timeout_add(500, self.check_format_job)
+        GLib.timeout_add(500, self.check_format_job)
 
     def format_job_done(self, rc):
-        self.format_progressbar.set_fraction(1.0)
+        self.set_progress(1.0)
         if rc == 0:
             message = _('The USB stick was formatted successfully.')
             self.logger(message)
@@ -364,7 +387,7 @@ class PearlStick:
 
     def do_write(self, widget):
         if self.debug:
-            print "DEBUG: Write %s to %s" % (self.chooser.get_filename(), self.dev)
+            print("DEBUG: Write %s to %s" % (self.chooser.get_filename(), self.dev))
             return
 
         self.go_button.set_sensitive(False)
@@ -373,7 +396,7 @@ class PearlStick:
         source = self.chooser.get_filename()
         target = self.dev
         self.logger(_('Image:') + ' ' + source)
-        self.logger(_('USB stick:')+ ' ' + self.dev)
+        self.logger(_('USB stick:') + ' ' + self.dev)
 
         if os.geteuid() > 0:
             self.raw_write(source, target)
@@ -387,23 +410,38 @@ class PearlStick:
                 self.confirm_dialog.hide()
                 self.set_iso_sensitive()
 
-    def set_progress_bar_fraction(self, size):
-        self.progress.set_fraction(size)
-        str_progress = "%3.0f%%" % (float(size)*100)
-        self.progress.set_text(str_progress)
-        self.window.set_title("%s - %s" % (str_progress, _("USB Image Writer")))
+    def set_progress(self, size):
+        self.progressbar.set_fraction(size)
+        str_progress = "%3.0f%%" % (float(size) * 100)
+        int_progress = int(float(size) * 100)
+        self.progressbar.set_text(str_progress)
+        if self.mode == "normal":
+            self.window.set_title("%s - %s" % (str_progress, _("USB Image Writer")))
+        else:
+            self.window.set_title("%s - %s" % (str_progress, _("USB Stick Formatter")))
+        XApp.set_window_progress_pulse(self.window, False)
+        XApp.set_window_progress(self.window, int_progress)
+
+    def pulse_progress(self):
+        self.progressbar.pulse()
+        if self.mode == "normal":
+            self.window.set_title( _("USB Image Writer"))
+        else:
+            self.window.set_title( _("USB Stick Formatter"))
+        XApp.set_window_progress_pulse(self.window, True)
 
     def update_progress(self, fd, condition):
         if Using_Unity:
             launcher.set_property("progress_visible", True)
-        if condition  is GLib.IO_IN:
+        if condition is GLib.IO_IN:
             line = fd.readline()
+            # noinspection PyBroadException
             try:
                 size = float(line.strip())
                 progress = round(size * 100)
                 if progress > self.write_progress:
                     self.write_progress = progress
-                    GObject.idle_add(self.set_progress_bar_fraction, size)
+                    GLib.idle_add(self.set_progress, size)
                     if Using_Unity:
                         launcher.set_property("progress", size)
             except:
@@ -418,24 +456,30 @@ class PearlStick:
         if self.process.returncode is None:
             return True
         else:
-            GObject.idle_add(self.write_job_done, self.process.returncode)
+            GLib.idle_add(self.write_job_done, self.process.returncode)
             self.process = None
             return False
 
     def raw_write(self, source, target):
-        self.progress.set_sensitive(True)
-        self.progress.set_text(_('Writing %(VAR_FILE)s to %(VAR_DEV)s') % {'VAR_FILE': source.split('/')[-1], 'VAR_DEV': self.dev})
-        self.logger(_('Starting copy from %(VAR_SOURCE)s to %(VAR_TARGET)s') % {'VAR_SOURCE':source, 'VAR_TARGET':target})
+        self.progressbar.set_sensitive(True)
+        self.progressbar.set_text(
+            _('Writing %(VAR_FILE)s to %(VAR_DEV)s') % {'VAR_FILE': source.split('/')[-1], 'VAR_DEV': self.dev})
+        self.logger(
+            _('Starting copy from %(VAR_SOURCE)s to %(VAR_TARGET)s') % {'VAR_SOURCE': source, 'VAR_TARGET': target})
 
         if os.geteuid() > 0:
-            launcher='pkexec'
-            self.process = Popen([launcher,'/usr/bin/python2', '-u', '/usr/lib/pearlstick/raw_write.py','-s',source,'-t',target], shell=False, stdout=PIPE, preexec_fn=os.setsid)
+            polkit_exec = 'pkexec'
+            self.process = Popen(
+                [polkit_exec, '/usr/bin/python3', '-u', '/usr/lib/pearlstick/raw_write.py', '-s', source, '-t', target],
+                shell=False, stdout=PIPE, preexec_fn=os.setsid)
         else:
-            self.process = Popen(['/usr/bin/python2', '-u', '/usr/lib/pearlstick/raw_write.py','-s',source,'-t',target], shell=False, stdout=PIPE, preexec_fn=os.setsid)
+            self.process = Popen(
+                ['/usr/bin/python3', '-u', '/usr/lib/pearlstick/raw_write.py', '-s', source, '-t', target],
+                shell=False, stdout=PIPE, preexec_fn=os.setsid)
 
         self.write_progress = 0
-        self.source_id = GLib.io_add_watch(self.process.stdout, GLib.IO_IN|GLib.IO_HUP, self.update_progress)
-        GObject.timeout_add(500, self.check_write_job)
+        self.source_id = GLib.io_add_watch(self.process.stdout, GLib.IO_IN | GLib.IO_HUP, self.update_progress)
+        GLib.timeout_add(500, self.check_write_job)
 
     def write_job_done(self, rc):
         if rc == 0:
@@ -443,7 +487,7 @@ class PearlStick:
                 launcher.set_property("progress_visible", False)
                 launcher.set_property("urgent", True)
             message = _('The image was successfully written.')
-            self.set_progress_bar_fraction(1.0)
+            self.set_progress(1.0)
             self.logger(message)
             self.success(_('The image was successfully written.'))
             return False
@@ -459,7 +503,7 @@ class PearlStick:
         self.emergency(message)
         return False
 
-    def success(self,message):
+    def success(self, message):
         label = self.wTree.get_object("label5")
         label.set_text(message)
         if self.mode == "normal":
@@ -473,7 +517,7 @@ class PearlStick:
             self.final_unsensitive()
         label = self.wTree.get_object("label6")
         label.set_text(message)
-        #self.expander.set_expanded(True)
+        # self.expander.set_expanded(True)
         mark = self.log.create_mark("end", self.log.get_end_iter(), False)
         self.logview.scroll_to_mark(mark, 0.05, True, 0.0, 1.0)
         resp = self.emergency_dialog.run()
@@ -484,9 +528,11 @@ class PearlStick:
         self.chooser.set_sensitive(False)
         self.devicelist.set_sensitive(False)
         self.go_button.set_sensitive(False)
-        self.progress = self.wTree.get_object("progressbar")
-        self.progress.set_sensitive(False)
-        self.window.set_title(_("USB Image Writer"))
+        self.progressbar.set_sensitive(False)
+        if self.mode == "normal":
+            self.window.set_title(_("USB Image Writer"))
+        else:
+            self.window.set_title(_("USB Stick Formatter"))     
 
     def close(self, widget):
         self.write_logfile()
@@ -503,29 +549,32 @@ class PearlStick:
     def write_logfile(self):
         start = self.log.get_start_iter()
         end = self.log.get_end_iter()
-        print self.log.get_text(start, end, False)
+        print(self.log.get_text(start, end, False))
 
     def logger(self, text):
-        self.log.insert_at_cursor(text+"\n")
+        self.log.insert_at_cursor(text + "\n")
 
     def activate_devicelist(self):
         self.devicelist.set_sensitive(True)
         self.expander.set_sensitive(True)
         self.label.set_sensitive(True)
 
-    def confirm_cancel(self,widget):
+    def confirm_cancel(self, widget):
         self.confirm_dialog.hide()
-        if self.mode == "normal": self.set_iso_sensitive()
-        if self.mode == "format": self.set_format_sensitive()
+        if self.mode == "normal":
+            self.set_iso_sensitive()
+        if self.mode == "format":
+            self.set_format_sensitive()
 
-    def emergency_ok(self,widget):
+    def emergency_ok(self, widget):
         self.emergency_dialog.hide()
-        if self.mode == "normal": self.set_iso_sensitive()
+        if self.mode == "normal":
+            self.set_iso_sensitive()
         if self.mode == "format":
             self.set_format_sensitive()
             self.go_button.set_sensitive(False)
 
-    def success_ok(self,widget):
+    def success_ok(self, widget):
         self.success_dialog.hide()
         if self.mode == "normal":
             self.set_iso_sensitive()
@@ -544,25 +593,28 @@ class PearlStick:
         self.devicelist.set_sensitive(True)
         self.go_button.set_sensitive(True)
 
+
 if __name__ == "__main__":
 
-    usb_path=None
-    iso_path=None
-    filesystem=None
-    mode=None
+    usb_path = None
+    iso_path = None
+    filesystem = None
+    mode = None
+
 
     def usage():
-        print "Usage: pearlstick [--debug] -m [format|iso]              : mode (format usb stick or burn iso image)"
-        print "       pearlstick [--debug] -m iso [-i|--iso] iso_path"
-        print "       pearlstick [--debug] -m format [-u|--usb] usb_device "
-        print "                           [-f|--filesystem] filesystem"
-        exit (0)
+        print("Usage: pearlstick [--debug] -m [format|iso]              : mode (format usb stick or burn iso image)")
+        print("       pearlstick [--debug] -m iso [-i|--iso] iso_path")
+        print("       pearlstick [--debug] -m format [-u|--usb] usb_device ")
+        print("                           [-f|--filesystem] filesystem")
+        exit(0)
+
 
     try:
-        opts, args = getopt.getopt(sys.argv[1:], "hm:i:u:f:", ["debug", "help", "mode=", "iso=","usb=","filesystem="])
-    except getopt.error, msg:
-        print msg
-        print "for help use --help"
+        opts, args = getopt.getopt(sys.argv[1:], "hm:i:u:f:", ["debug", "help", "mode=", "iso=", "usb=", "filesystem="])
+    except getopt.error as msg:
+        print(msg)
+        print("for help use --help")
         sys.exit(2)
 
     debug = False
@@ -572,20 +624,21 @@ if __name__ == "__main__":
         elif o in ("-i", "--iso"):
             iso_path = a
         elif o in ("-u", "--usb"):
-            # hack. KDE Solid application gives partition name not device name. Need to remove extra digit from the string.
+            # hack. KDE Solid application gives partition name not device name.
+            # Need to remove extra digit from the string.
             # ie. /dev/sdj1 -> /dev/sdj
             usb_path = ''.join([i for i in a if not i.isdigit()])
         elif o in ("-f", "--filesystem"):
             filesystem = a
         elif o in ("-m", "--mode"):
-            mode=a
-        elif o in ("--debug"):
+            mode = a
+        elif o in "--debug":
             debug = True
 
     argc = len(sys.argv)
     if argc > 8:
-        print "Too many arguments"
-        print "for help use --help"
+        print("Too many arguments")
+        print("for help use --help")
         exit(2)
 
     # Mandatory argument
@@ -594,7 +647,7 @@ if __name__ == "__main__":
 
     PearlStick(iso_path, usb_path, filesystem, mode, debug)
 
-    #start the main loop
-    #mainloop = GObject.MainLoop()
-    #mainloop.run()
+    # start the main loop
+    # mainloop = GObject.MainLoop()
+    # mainloop.run()
     Gtk.main()
